@@ -17,12 +17,12 @@ from gettext import gettext as _
 from urllib.parse import urlparse
 from random import randint
 
-from lollypop.define import App, Type, ResponsiveType
+from lollypop.define import App, Type, ResponsiveType, SelectionListType
 from lollypop.objects import Album
 from lollypop.loader import Loader
 from lollypop.selectionlist import SelectionList
 from lollypop.view_container import ViewContainer
-from lollypop.view import View
+from lollypop.view import View, MessageView
 from lollypop.progressbar import ProgressBar
 
 
@@ -118,39 +118,23 @@ class Container(Gtk.Overlay):
         view.show()
         self.__stack.add(view)
         self.__stack.set_visible_child(view)
-        if hasattr(current, "disable_overlay"):
-            current.disable_overlay()
+        current.disable_overlay()
 
-    def show_playlist_manager(self, object):
+    def show_playlist_manager(self, obj):
         """
             Show playlist manager for object_id
             Current view stay present in ViewContainer
-            @param object as Track/Album/Disc
+            @param obj as Track/Album
         """
-        from lollypop.view_playlists import PlaylistsManageView
+        from lollypop.view_playlists_manager import PlaylistsManagerView
         current = self.__stack.get_visible_child()
-        view = PlaylistsManageView(object)
-        view.populate()
+        view = PlaylistsManagerView(obj)
+        view.populate(App().playlists.get_ids())
         view.show()
         self.__stack.add(view)
         self.__stack.set_visible_child(view)
         current.disable_overlay()
 
-    def show_playlist_editor(self, playlist_id):
-        """
-            Show playlist editor for playlist
-            Current view stay present in ViewContainer
-            @param playlist id as int
-            @param playlist name as str
-        """
-        from lollypop.view_playlists import PlaylistEditView
-        view = PlaylistEditView(playlist_id)
-        view.show()
-        self.__stack.add(view)
-        self.__stack.set_visible_child(view)
-        self.__stack.clean_old_views(view)
-        view.populate()
-
     def get_view_width(self):
         """
             Return view width
@@ -324,10 +308,12 @@ class Container(Gtk.Overlay):
     @property
     def view(self):
         """
-            Disable overlays
+            Get current view
         """
         view = self.__stack.get_visible_child()
         if view is not None and not isinstance(view, View):
+            # Should have commented this, why?
+            # FIXME
             for child in self.__stack.get_children():
                 if isinstance(child, View):
                     view = child
@@ -394,9 +380,9 @@ class Container(Gtk.Overlay):
         vgrid = Gtk.Grid()
         vgrid.set_orientation(Gtk.Orientation.VERTICAL)
 
-        self.__list_one = SelectionList(SelectionList.Type.LIST_ONE)
+        self.__list_one = SelectionList(SelectionListType.LIST_ONE)
         self.__list_one.show()
-        self.__list_two = SelectionList(SelectionList.Type.LIST_TWO)
+        self.__list_two = SelectionList(SelectionListType.LIST_TWO)
         self.__list_one.connect("item-selected", self.__on_list_one_selected)
         self.__list_one.connect("populated", self.__on_list_populated)
         self.__list_one.connect("pass-focus", self.__on_pass_focus)
@@ -453,13 +439,10 @@ class Container(Gtk.Overlay):
         """
         if not self.__list_two_state:
             return
-        # Get list two ids (only on save state)
-        list_two_ids = [Type.NONE]
-        if App().settings.get_value("save-state"):
-            list_two_ids = []
-            for i in self.__list_two_state:
-                if isinstance(i, int):
-                    list_two_ids.append(i)
+        list_two_ids = []
+        for i in self.__list_two_state:
+            if isinstance(i, int):
+                list_two_ids.append(i)
         if list_two_ids and list_two_ids[0] != Type.NONE:
             self.__list_two.select_ids(list_two_ids)
         self.__list_two_state = []
@@ -498,7 +481,7 @@ class Container(Gtk.Overlay):
             return genres
 
         def setup(genres):
-            selection_list.mark_as(SelectionList.Type.GENRE)
+            selection_list.mark_as(SelectionListType.GENRE)
             items = selection_list.get_headers()
             items += genres
             if update:
@@ -523,9 +506,9 @@ class Container(Gtk.Overlay):
             return (artists, compilations)
 
         def setup(artists, compilations):
-            mask = SelectionList.Type.ARTISTS
+            mask = SelectionListType.ARTISTS
             if compilations:
-                mask |= SelectionList.Type.COMPILATIONS
+                mask |= SelectionListType.COMPILATIONS
             selection_list.mark_as(mask)
             items = selection_list.get_headers()
             items += artists
@@ -551,20 +534,45 @@ class Container(Gtk.Overlay):
             @param update as bool
             @param type as int
         """
-        self.__list_two.mark_as(SelectionList.Type.PLAYLISTS)
+        self.__list_two.mark_as(SelectionListType.PLAYLISTS)
         if type == Type.PLAYLISTS:
             items = self.__list_two.get_playlist_headers()
             items += App().playlists.get()
         else:
-            years = App().albums.get_years()
+            (years, unknown) = App().albums.get_years()
             items = [(year, str(year)) for year in sorted(years)]
-            items.insert(0, (Type.NONE, _("Unknown")))
+            if unknown:
+                items.insert(0, (Type.NONE, _("Unknown")))
         if update:
             self.__list_two.update_values(items)
         else:
             self.__list_two.populate(items)
             self.__restore_list_two_state()
 
+    def __update_list_device(self, selection_list):
+        """
+            Setup list for device
+            @param list as SelectionList
+            @thread safe
+        """
+        def load():
+            artists = App().artists.get()
+            compilations = App().albums.get_compilation_ids()
+            return (artists, compilations)
+
+        def setup(artists, compilations):
+            items = [(Type.ALL, _("Synced albums"))]
+            items.append((Type.PLAYLISTS, _("Playlists")))
+            if compilations:
+                items.append((Type.COMPILATIONS, _("Compilations")))
+                items.append((Type.SEPARATOR, ""))
+            items += artists
+            selection_list.mark_as(SelectionListType.ARTISTS)
+            selection_list.populate(items)
+        loader = Loader(target=load, view=selection_list,
+                        on_finished=lambda r: setup(*r))
+        loader.start()
+
     def __stop_current_view(self):
         """
             Stop current view
@@ -581,7 +589,7 @@ class Container(Gtk.Overlay):
             @param device id as int
             @return View
         """
-        from lollypop.view_device import DeviceView, DeviceLocked
+        from lollypop.view_device import DeviceView
         self.__stop_current_view()
         device = self.__devices[device_id]
         device_view = None
@@ -592,20 +600,17 @@ class Container(Gtk.Overlay):
                 if child.device.uri == device.uri:
                     device_view = child
                     break
-            elif isinstance(child, DeviceLocked):
-                device_view = child
-                break
 
         # If no view available, get a new one
         if device_view is None:
             files = DeviceView.get_files(device.uri)
             if files:
                 device_view = DeviceView(device)
-                device_view.populate()
                 self.__stack.add_named(device_view, device.uri)
             else:
-                device_view = DeviceLocked()
+                device_view = MessageView(_("Please unlock your device"))
                 self.__stack.add(device_view)
+            device_view.populate()
             device_view.show()
         return device_view
 
@@ -642,11 +647,11 @@ class Container(Gtk.Overlay):
             Get album view for decades
         """
         def load():
-            years = sorted(App().albums.get_years())
+            (years, unknown) = App().albums.get_years()
             decades = []
             decade = []
             current_d = None
-            for year in years:
+            for year in sorted(years):
                 d = year // 10
                 if current_d is not None and current_d != d:
                     current_d = d
@@ -676,6 +681,7 @@ class Container(Gtk.Overlay):
         def load():
             items = []
             for year in years:
+                items += App().albums.get_compilations_for_year(year)
                 items += App().albums.get_albums_for_year(year)
             return [Album(album_id, [Type.YEARS], [])
                     for album_id in items]
@@ -685,7 +691,7 @@ class Container(Gtk.Overlay):
             view = AlbumsListView(ResponsiveType.LIST)
         else:
             from lollypop.view_albums_box import AlbumsBoxView
-            view = AlbumsBoxView([Type.YEARS], [])
+            view = AlbumsBoxView([Type.YEARS], years)
         loader = Loader(target=load, view=view)
         loader.start()
         view.show()
@@ -749,39 +755,32 @@ class Container(Gtk.Overlay):
             @param playlist ids as [int]
             @return View
         """
+        from lollypop.view_playlists_manager import PlaylistsManagerView
+
         def load():
             track_ids = []
             for playlist_id in playlist_ids:
-                if playlist_id == Type.POPULARS:
-                    tracks = App().tracks.get_rated()
-                    for track in App().tracks.get_populars():
-                        tracks.append(track)
-                elif playlist_id == Type.RECENTS:
-                    tracks = App().tracks.get_recently_listened_to()
-                elif playlist_id == Type.NEVER:
-                    tracks = App().tracks.get_never_listened_to()
-                elif playlist_id == Type.RANDOMS:
-                    tracks = App().tracks.get_randoms()
-                elif playlist_id == Type.LOVED:
-                    tracks = App().playlists.get_track_ids_sorted(playlist_id)
+                # We want track_ids from manager
+                # to show same albums for Type.RANDOMS
+                if isinstance(self.view, PlaylistsManagerView):
+                    _track_ids = self.view.get_track_ids_for_playlist_id(
+                        playlist_id)
                 else:
-                    tracks = App().playlists.get_track_ids(playlist_id)
-                for track_id in tracks:
+                    _track_ids = App().playlists.get_track_ids(playlist_id)
+                for track_id in _track_ids:
                     if track_id not in track_ids:
                         track_ids.append(track_id)
             return track_ids
 
         self.__stop_current_view()
-        view = None
         if playlist_ids:
             from lollypop.view_playlists import PlaylistsView
             view = PlaylistsView(playlist_ids)
             loader = Loader(target=load, view=view)
             loader.start()
         else:
-            from lollypop.view_playlists import PlaylistsManageView
-            view = PlaylistsManageView(None)
-            view.populate()
+            view = PlaylistsManagerView()
+            view.populate(App().playlists.get_ids())
         view.show()
         return view
 
@@ -790,9 +789,15 @@ class Container(Gtk.Overlay):
             Get radios view
         """
         from lollypop.view_radios import RadiosView
+        from lollypop.radios import Radios
         self.__stop_current_view()
-        view = RadiosView()
-        view.populate()
+        radios = Radios()
+        radio_ids = radios.get_ids()
+        if radio_ids:
+            view = RadiosView(radios)
+            view.populate(radio_ids)
+        else:
+            view = MessageView(_("No favorite radios"))
         view.show()
         return view
 
@@ -872,7 +877,7 @@ class Container(Gtk.Overlay):
             self.__update_list_playlists(False, selected_ids[0])
             self.__list_two.show()
         elif (selected_ids[0] > 0 or selected_ids[0] == Type.ALL) and\
-                self.__list_one.type & SelectionList.Type.GENRE:
+                self.__list_one.type & SelectionListType.GENRE:
             self.__update_list_artists(self.__list_two, selected_ids, False)
             self.__list_two.show()
         else:
@@ -882,6 +887,8 @@ class Container(Gtk.Overlay):
             if not list_two_about_to_do_selection:
                 view = self.__get_view_playlists()
         elif Type.DEVICES - 999 < selected_ids[0] < Type.DEVICES:
+            self.__update_list_device(self.__list_two)
+            self.__list_two.show()
             view = self.__get_view_device(selected_ids[0])
         elif selected_ids[0] in [Type.POPULARS,
                                  Type.LOVED,
@@ -891,7 +898,7 @@ class Container(Gtk.Overlay):
             view = self.__get_view_albums(selected_ids, [])
         elif selected_ids[0] == Type.RADIOS:
             view = self.__get_view_radios()
-        elif selection_list.type & SelectionList.Type.ARTISTS:
+        elif selection_list.type & SelectionListType.ARTISTS:
             if selected_ids[0] == Type.ALL:
                 view = self.__get_view_albums(selected_ids, [])
             elif selected_ids[0] == Type.COMPILATIONS:
@@ -913,6 +920,7 @@ class Container(Gtk.Overlay):
                     and self.__list_two.is_visible()\
                     and (
                         selected_ids[0] >= 0 or
+                        Type.DEVICES - 999 < selected_ids[0] < Type.DEVICES or
                         selected_ids[0] in [Type.PLAYLISTS,
                                             Type.YEARS,
                                             Type.ALL]):
@@ -938,6 +946,16 @@ class Container(Gtk.Overlay):
         selected_ids = self.__list_two.selected_ids
         if not selected_ids or not genre_ids:
             return
+        # Just update the view
+        if Type.DEVICES - 999 < genre_ids[0] < Type.DEVICES:
+            from lollypop.view_device import DeviceView
+            # Search for an existing view
+            for view in self.__stack.get_children():
+                if isinstance(view, DeviceView):
+                    view.populate(selection_list.selected_ids)
+                    self.__stack.set_visible_child(view)
+            view = self.__get_view_device(genre_ids[0])
+            return
         if genre_ids[0] == Type.PLAYLISTS:
             view = self.__get_view_playlists(selected_ids)
         elif genre_ids[0] == Type.YEARS:
