@@ -59,13 +59,23 @@ class ArtSize:
     ARTIST_SMALL = 60
     HEADER = 100
     BIG = 200
-    YEAR = 300
+    ROUNDED = 300
     FULLSCREEN = 500
     ARTIST = 800
     MONSTER = 900
     MAX = 4000
 
 
+class SelectionListType:
+        LIST_ONE = 1 << 1
+        LIST_TWO = 1 << 2
+        LIST_DEVICE = 1 << 3
+        ARTISTS = 1 << 4
+        GENRE = 1 << 5
+        PLAYLISTS = 1 << 6
+        COMPILATIONS = 1 << 7
+
+
 class Shuffle:
     NONE = 0             # No shuffle
     TRACKS = 1           # Shuffle by tracks on genre
@@ -104,7 +114,7 @@ class Type:
     NEVER = -6
     PLAYLISTS = -7
     RADIOS = -8
-    EXTERNALS = -9
+    UNUSED_FIXME = -9
     SEARCH = -10
     NOPARTY = -11
     YEARS = -12
@@ -115,11 +125,6 @@ class Type:
     COMPILATIONS = -2001
 
 
-PROXY_BUS = "org.gnome.Lollypop.Portal"
-PROXY_PATH = "/org/gnome/LollypopPortal"
-PROXY_INTERFACE = "org.gnome.Lollypop.Portal"
-
-
 SPOTIFY_CLIENT_ID = "0b144843878a46b2b12e0958c342c3ac"
 SPOTIFY_SECRET = "265ab8e057684f1b9e69e0c58f4881c1"
 
