@@ -75,7 +75,7 @@ class LastFM(LastFMNetwork, LibreFMNetwork):
             LastFMNetwork.__init__(self,
                                    api_key=self.__API_KEY,
                                    api_secret=self.__API_SECRET)
-        self.connect()
+        self.connect(True)
 
     def connect(self, full_sync=False, callback=None, *args):
         """
@@ -365,7 +365,7 @@ class LastFM(LastFMNetwork, LibreFMNetwork):
         """
             Populate loved tracks playlist
         """
-        if not self.available:
+        if not self.available or App().playlists.get_track_ids(Type.LOVED):
             return
         try:
             tracks = []
