@@ -12,11 +12,12 @@
 
 from gi.repository import Gtk, Gdk
 
-from lollypop.controllers import InfoController, ProgressController
+from lollypop.controller_information import InformationController
+from lollypop.controller_progress import ProgressController
 from lollypop.define import App, WindowSize
 
 
-class MiniPlayer(Gtk.Bin, InfoController, ProgressController):
+class MiniPlayer(Gtk.Bin, InformationController, ProgressController):
     """
         Toolbar end
     """
@@ -28,7 +29,7 @@ class MiniPlayer(Gtk.Bin, InfoController, ProgressController):
         """
         self.__width = width
         Gtk.Bin.__init__(self)
-        InfoController.__init__(self)
+        InformationController.__init__(self)
         ProgressController.__init__(self)
         builder = Gtk.Builder()
         builder.add_from_resource("/org/gnome/Lollypop/MiniPlayer.ui")
@@ -50,8 +51,8 @@ class MiniPlayer(Gtk.Bin, InfoController, ProgressController):
                                                  self.__on_status_changed)
         self.__on_current_changed(App().player)
         if App().player.current_track.id is not None:
-            self._update_position()
-            self.__on_status_changed(App().player)
+            self.update_position()
+            ProgressController.on_status_changed(self, App().player)
         self.add(builder.get_object("widget"))
 
     def update_cover(self, width):
@@ -60,7 +61,7 @@ class MiniPlayer(Gtk.Bin, InfoController, ProgressController):
             @param width as int
         """
         self.__width = width
-        InfoController.on_current_changed(self, width, None)
+        InformationController.on_current_changed(self, width, None)
 
     def do_get_preferred_width(self):
         """
@@ -80,7 +81,6 @@ class MiniPlayer(Gtk.Bin, InfoController, ProgressController):
         """
             Remove signal
         """
-        Gtk.Bin.do_destroy(self)
         ProgressController.do_destroy(self)
         App().player.disconnect(self.__signal_id1)
         App().player.disconnect(self.__signal_id2)
@@ -105,7 +105,7 @@ class MiniPlayer(Gtk.Bin, InfoController, ProgressController):
                     App().player.current_track,
                     ToolbarMenu(App().player.current_track))
                 popover.set_relative_to(self)
-                popover.show()
+                popover.popup()
         return True
 
     def _on_labels_realize(self, eventbox):
@@ -125,7 +125,7 @@ class MiniPlayer(Gtk.Bin, InfoController, ProgressController):
         """
         if App().player.current_track.id is not None:
             self.show()
-        InfoController.on_current_changed(self, self.__width, None)
+        InformationController.on_current_changed(self, self.__width, None)
         ProgressController.on_current_changed(self, player)
 
     def __on_status_changed(self, player):
