@@ -46,6 +46,7 @@ class Player(BinPlayer, QueuePlayer, PlaylistPlayer, RadioPlayer,
         self.update_crossfading()
         self.__do_not_update_next = False
         App().settings.connect("changed::playback", self.__on_playback_changed)
+        self._albums_backup = []
 
     def prev(self):
         """
@@ -134,10 +135,28 @@ class Player(BinPlayer, QueuePlayer, PlaylistPlayer, RadioPlayer,
             if not self.is_party or self._next_track.album_id == album.id:
                 self.set_next()
             self.set_prev()
-            self.emit("album-added", album.id)
+            self.emit("album-removed", album.id)
         except Exception as e:
             Logger.error("Player::remove_album(): %s" % e)
 
+    def remove_album_by_id(self, album_id):
+        """
+            Remove album id from albums
+            @param album_id as int
+        """
+        try:
+            idx = self.album_ids.index(album_id)
+            album = self._albums[idx]
+            self._albums.remove(album)
+            if album in self._albums_backup:
+                self._albums_backup.remove(album)
+            if not self.is_party or self._next_track.album_id == album.id:
+                self.set_next()
+            self.set_prev()
+            self.emit("album-removed", album.id)
+        except Exception as e:
+            Logger.error("Player::remove_album_by_id(): %s" % e)
+
     def play_album(self, album):
         """
             Play album
@@ -156,12 +175,12 @@ class Player(BinPlayer, QueuePlayer, PlaylistPlayer, RadioPlayer,
         self.load(track)
         self._albums = [album]
 
-    def play_albums(self, track, genre_ids, artist_ids):
+    def play_albums(self, track, filter1_ids, filter2_ids):
         """
             Play albums related to track/genre_ids/artist_ids
-            @param track as Track
-            @param genre_ids as [int]
-            @param artist_ids as [int]
+            @param track as Track/None
+            @param filter1_ids as [int]
+            @param filter2_ids as [int]
         """
         self._albums = []
         album_ids = []
@@ -170,60 +189,61 @@ class Player(BinPlayer, QueuePlayer, PlaylistPlayer, RadioPlayer,
         self._playlist_tracks = []
         self._playlist_ids = []
         # We are in all artists
-        if (genre_ids and genre_ids[0] == Type.ALL) or\
-           (artist_ids and artist_ids[0] == Type.ALL):
+        if (filter1_ids and filter1_ids[0] == Type.ALL) or\
+           (filter2_ids and filter2_ids[0] == Type.ALL):
             # Genres: all, Artists: compilations
-            if artist_ids and artist_ids[0] == Type.COMPILATIONS:
+            if filter2_ids and filter2_ids[0] == Type.COMPILATIONS:
                 album_ids = App().albums.get_compilation_ids()
             # Genres: all, Artists: ids
-            elif artist_ids and artist_ids[0] != Type.ALL:
-                album_ids += App().albums.get_ids(artist_ids)
+            elif filter2_ids and filter2_ids[0] != Type.ALL:
+                album_ids += App().albums.get_ids(filter2_ids)
             # Genres: all, Artists: all
             else:
                 if App().settings.get_value("show-compilations-in-album-view"):
                     album_ids += App().albums.get_compilation_ids()
                 album_ids += App().albums.get_ids()
         # We are in populars view, add popular albums
-        elif genre_ids and genre_ids[0] == Type.POPULARS:
+        elif filter1_ids and filter1_ids[0] == Type.POPULARS:
             album_ids = App().albums.get_populars()
         # We are in loved view, add loved albums
-        elif genre_ids and genre_ids[0] == Type.LOVED:
+        elif filter1_ids and filter1_ids[0] == Type.LOVED:
             album_ids = App().albums.get_loves()
         # We are in recents view, add recent albums
-        elif genre_ids and genre_ids[0] == Type.RECENTS:
+        elif filter1_ids and filter1_ids[0] == Type.RECENTS:
             album_ids = App().albums.get_recents()
         # We are in randoms view, add random albums
-        elif genre_ids and genre_ids[0] == Type.RANDOMS:
+        elif filter1_ids and filter1_ids[0] == Type.RANDOMS:
             album_ids = App().albums.get_cached_randoms()
         # We are in compilation view without genre
-        elif genre_ids and genre_ids[0] == Type.COMPILATIONS:
+        elif filter1_ids and filter1_ids[0] == Type.COMPILATIONS:
             album_ids = App().albums.get_compilation_ids()
         # We are in years view
-        elif genre_ids and genre_ids[0] == Type.YEARS:
-            # Only way to get years
-            years = App().window.container.list_two.selected_ids
+        elif filter1_ids and filter1_ids[0] == Type.YEARS:
             album_ids = []
-            for year in years:
+            for year in filter2_ids:
                 album_ids += App().albums.get_albums_for_year(year)
+                album_ids += App().albums.get_compilations_for_year(year)
         # Add albums for artists/genres
         else:
             # If we are not in compilation view and show compilation is on,
             # add compilations
-            if artist_ids and artist_ids[0] == Type.COMPILATIONS:
-                album_ids += App().albums.get_compilation_ids(genre_ids)
+            if filter2_ids and filter2_ids[0] == Type.COMPILATIONS:
+                album_ids += App().albums.get_compilation_ids(filter1_ids)
             else:
-                if not artist_ids and\
+                if not filter2_ids and\
                         App().settings.get_value(
                             "show-compilations-in-album-view"):
-                    album_ids += App().albums.get_compilation_ids(genre_ids)
-                album_ids += App().albums.get_ids(artist_ids, genre_ids)
+                    album_ids += App().albums.get_compilation_ids(filter1_ids)
+                album_ids += App().albums.get_ids(filter2_ids, filter1_ids)
         # Create album objects
         for album_id in album_ids:
-            album = Album(album_id, genre_ids, artist_ids)
+            album = Album(album_id, filter1_ids, filter2_ids)
             self._albums.append(album)
             # Get track from album
             # to make Player.current_track present in Player.albums
-            if album.id == track.album.id:
+            if track is None:
+                track = album.tracks[0]
+            elif album.id == track.album.id:
                 index = album.track_ids.index(track.id)
                 track = album.tracks[index]
         self.load(track)
@@ -268,30 +288,20 @@ class Player(BinPlayer, QueuePlayer, PlaylistPlayer, RadioPlayer,
                     track.set_radio(name, url)
                     self.load(track, is_playing)
                 elif App().tracks.get_uri(track_id) != "":
-                    track = Track(track_id)
-                    self._load_track(track)
-                    # We set this initial state
-                    # because seek while failed otherwise
-                    self.pause()
-                    if playlist_ids:
-                        track_ids = []
-                        for playlist_id in playlist_ids:
-                            if playlist_id == Type.POPULARS:
-                                track_ids = App().tracks.get_populars()
-                            elif playlist_id == Type.RECENTS:
-                                track_ids = App().tracks.\
-                                    get_recently_listened_to()
-                            elif playlist_id == Type.NEVER:
-                                track_ids = App().tracks.\
-                                    get_never_listened_to()
-                            elif playlist_id == Type.RANDOMS:
-                                track_ids = App().tracks.get_randoms()
-                            else:
-                                track_ids = App().playlists.get_track_ids(
-                                    playlist_id)
-                            self.populate_playlist_by_track_ids(
-                                list(set(track_ids)),
-                                playlist_ids)
+                    for playlist_id in playlist_ids:
+                        track_ids = App().playlists.get_track_ids(
+                            playlist_id)
+                        tracks = [Track(track_id)
+                                  for track_id in track_ids]
+                        wanted = None
+                        for track in tracks:
+                            if track.id == track_id:
+                                wanted = track
+                                break
+                        if wanted is not None:
+                            self._load_track(wanted)
+                        App().player.populate_playlist_by_tracks(tracks,
+                                                                 playlist_ids)
                     else:
                         if was_party:
                             self.emit("party-changed", True)
@@ -390,12 +400,10 @@ class Player(BinPlayer, QueuePlayer, PlaylistPlayer, RadioPlayer,
             # We send this signal to update next popover
             self.emit("queue-changed")
         elif self._current_track.id is not None:
-            pos = self._albums.index(self._current_track.album)
-            if pos + 1 >= len(self._albums):
-                next_album = self._albums[0]
-            else:
-                next_album = self._albums[pos + 1]
-            self.load(next_album.tracks[0])
+            self.pause()
+            self.load(self._current_track.album.tracks[-1])
+            self.set_next()
+            self.next()
 
     def update_crossfading(self):
         """
@@ -457,6 +465,14 @@ class Player(BinPlayer, QueuePlayer, PlaylistPlayer, RadioPlayer,
         """
         return self._albums
 
+    @property
+    def album_ids(self):
+        """
+            Return albums ids
+            @return albums ids as [int]
+        """
+        return [album.id for album in self._albums]
+
 #######################
 # PROTECTED           #
 #######################
