@@ -22,13 +22,10 @@ class AlbumPopover(Gtk.Popover):
         Not an AlbumDetailedWidget because we want a lazy loading view
     """
 
-    def __init__(self, album, genre_ids,
-                 artist_ids, width, height, art_size=ArtSize.NONE):
+    def __init__(self, album, width, height, art_size=ArtSize.NONE):
         """
             Init popover
             @param album as Album
-            @param genre ids as [int]
-            @param artist ids as [int]
             @param width as int
             @param height as int
             @param art size as int
@@ -37,17 +34,14 @@ class AlbumPopover(Gtk.Popover):
         self.__height = height
         self.__width = width
         self.get_style_context().add_class("box-shadow")
-        view = ArtistAlbumsView(artist_ids, genre_ids, art_size)
+        view = ArtistAlbumsView(album.artist_ids, album.genre_ids, art_size)
         view.populate([album])
         if App().window.container.is_paned_stack:
-            for child in view.children:
-                child.hide_header_labels()
-
-        # Get height requested by child
-        album_widget = view.children[0]
-        album_widget.connect("size-allocate",
-                             self.__on_album_size_allocate,
-                             view)
+            view.hide_header_labels()
+        wanted_height = min(600,
+                            min(self.__height,
+                                view.children[0].requested_height))
+        view.set_property("height-request", wanted_height)
         view.show()
         self.add(view)
 
@@ -61,13 +55,3 @@ class AlbumPopover(Gtk.Popover):
 #######################
 # PRIVATE             #
 #######################
-    def __on_album_size_allocate(self, widget, allocation, view):
-        """
-            Update view height
-            @param widget as Gtk.Widget
-            @param allocation as Gtk.Allocation
-            @param view as ArtistAlbumsView
-        """
-        requested_height = widget.requested_height
-        wanted_height = min(600, min(self.__height, requested_height))
-        view.set_property("height-request", wanted_height)
