@@ -29,7 +29,7 @@ class ToolbarEnd(Gtk.Bin):
         """
         Gtk.Bin.__init__(self)
         self.set_hexpand(True)
-        self.__search = None
+        self.__search_popover = None
         self.__timeout_id = None
         builder = Gtk.Builder()
         builder.add_from_resource("/org/gnome/Lollypop/ToolbarEnd.ui")
@@ -77,8 +77,8 @@ class ToolbarEnd(Gtk.Bin):
         self.__next_popover = NextPopover()
         self.__next_popover.set_relative_to(self.__shuffle_button)
 
-        self.__search_button = builder.get_object("search-button")
-        self.__gesture = Gtk.GestureLongPress.new(self.__search_button)
+        self.__search_popover_button = builder.get_object("search-button")
+        self.__gesture = Gtk.GestureLongPress.new(self.__search_popover_button)
         self.__gesture.connect("pressed", self.__on_search_button_pressed)
         self.__gesture.connect("cancelled", self.__on_search_button_cancelled)
         search_action = Gio.SimpleAction.new("search", None)
@@ -88,7 +88,10 @@ class ToolbarEnd(Gtk.Bin):
         App().add_action(search_action)
         App().set_accels_for_action("app.search", ["<Control>f"])
 
-        self.__settings_button = builder.get_object("settings-button")
+        builder_menu = Gtk.Builder()
+        builder_menu.add_from_resource("/org/gnome/Lollypop/Appmenu.ui")
+        builder.get_object("settings-button").set_menu_model(
+            builder_menu.get_object("app-menu"))
 
         self.__list_button = builder.get_object("list-button")
         self.__list_button.set_property("has-tooltip", True)
@@ -116,21 +119,14 @@ class ToolbarEnd(Gtk.Bin):
         else:
             self.__shuffle_button.show()
             if self.__next_popover.should_be_shown():
-                self.__next_popover.show()
+                self.__next_popover.popup()
         # Remove another button
-        search_button_width = self.__search_button.get_allocated_width()
-        if width < WindowSize.MONSTER - search_button_width:
+        button_width = self.__search_popover_button.get_allocated_width()
+        if width < WindowSize.MONSTER - button_width:
             self.__list_button.hide()
         else:
             self.__list_button.show()
 
-    def setup_menu(self, menu):
-        """
-            Add an application menu to menu button
-            @parma: menu as Gio.Menu
-        """
-        self.__settings_button.set_menu_model(menu)
-
     def on_next_changed(self, player):
         """
             Show next popover
@@ -140,7 +136,7 @@ class ToolbarEnd(Gtk.Bin):
             if self.__next_popover.is_visible():
                 self.__next_popover.update()
             else:
-                self.__next_popover.show()
+                self.__next_popover.popup()
         else:
             self.__next_popover.hide()
 
@@ -149,8 +145,8 @@ class ToolbarEnd(Gtk.Bin):
             Search item
             @param search as str
         """
-        self.__on_search_short([])
-        self.__search.set_text(search)
+        self.__on_search_button_cancelled()
+        self.__search_popover.set_text(search)
 
     def show_list_popover(self, button):
         """
@@ -167,7 +163,7 @@ class ToolbarEnd(Gtk.Bin):
             from lollypop.pop_albums import AlbumsPopover
             popover = AlbumsPopover()
         popover.set_relative_to(button)
-        popover.show()
+        popover.popup()
         return popover
 
 #######################
@@ -200,7 +196,7 @@ class ToolbarEnd(Gtk.Bin):
         else:
             self.__next_popover.inhibit(False)
             if self.__next_popover.should_be_shown():
-                self.__next_popover.show()
+                self.__next_popover.popup()
 
     def _on_settings_button_toggled(self, button):
         """
@@ -213,7 +209,7 @@ class ToolbarEnd(Gtk.Bin):
         else:
             self.__next_popover.inhibit(False)
             if self.__next_popover.should_be_shown():
-                self.__next_popover.show()
+                self.__next_popover.popup()
 
 #######################
 # PRIVATE             #
@@ -297,19 +293,18 @@ class ToolbarEnd(Gtk.Bin):
         if App().window.container.view is not None:
             App().window.container.view.enable_filter()
 
-    def __on_search_button_cancelled(self, gesture):
+    def __on_search_button_cancelled(self, *ignore):
         """
             Show search popover
-            @param gesture as Gtk.GestureLongPress
         """
         self.__next_popover.hide()
         self.__next_popover.inhibit(True)
-        if self.__search is None:
+        if self.__search_popover is None:
             from lollypop.pop_search import SearchPopover
-            self.__search = SearchPopover()
-            self.__search.connect("closed", self.__on_popover_closed)
-        self.__search.set_relative_to(self.__search_button)
-        self.__search.show()
+            self.__search_popover = SearchPopover()
+            self.__search_popover.connect("closed", self.__on_popover_closed)
+        self.__search_popover.set_relative_to(self.__search_popover_button)
+        self.__search_popover.popup()
 
     def __set_shuffle_icon(self):
         """
@@ -416,7 +411,7 @@ class ToolbarEnd(Gtk.Bin):
         """
         self.__next_popover.inhibit(False)
         if self.__next_popover.should_be_shown():
-            self.__next_popover.show()
+            self.__next_popover.popup()
 
     def __on_list_button_query_tooltip(self, widget, x, y, keyboard, tooltip):
         """
