@@ -12,11 +12,11 @@
 
 from gi.repository import Gtk, Gdk, GLib
 
-from lollypop.controllers import InfoController
+from lollypop.controller_information import InformationController
 from lollypop.define import App, Type
 
 
-class ToolbarInfo(Gtk.Bin, InfoController):
+class ToolbarInfo(Gtk.Bin, InformationController):
     """
         Informations toolbar
     """
@@ -26,7 +26,7 @@ class ToolbarInfo(Gtk.Bin, InfoController):
             Init toolbar
         """
         Gtk.Bin.__init__(self)
-        InfoController.__init__(self)
+        InformationController.__init__(self)
         builder = Gtk.Builder()
         builder.add_from_resource("/org/gnome/Lollypop/ToolbarInfo.ui")
         builder.connect_signals(self)
@@ -91,7 +91,7 @@ class ToolbarInfo(Gtk.Bin, InfoController):
             Update widgets
             player as Player
         """
-        InfoController.on_current_changed(self, self.artsize, None)
+        InformationController.on_current_changed(self, self.artsize, None)
 
 #######################
 # PROTECTED           #
@@ -143,7 +143,7 @@ class ToolbarInfo(Gtk.Bin, InfoController):
             popover.set_relative_to(self._infobox)
         elif App().player.current_track.id == Type.RADIOS:
             popover = Gtk.Popover.new_from_model(self._infobox, menu)
-        popover.show()
+        popover.popup()
 
     def __on_infobox_button_press_event(self, eventbox, event):
         """
@@ -170,7 +170,7 @@ class ToolbarInfo(Gtk.Bin, InfoController):
                 popover = InformationPopover()
                 popover.populate()
             popover.set_relative_to(self._infobox)
-            popover.show()
+            popover.popup()
         else:
             self.__on_infobox_pressed(self.__gesture, 0, 0)
 
