@@ -10,15 +10,16 @@
 # You should have received a copy of the GNU General Public License
 # along with this program. If not, see <http://www.gnu.org/licenses/>.
 
-from gi.repository import Gtk, GLib
+from gi.repository import Gtk
 
-from lollypop.view import LazyLoadingView
+from lollypop.view_flowbox import FlowBoxView
 from lollypop.widgets_album_simple import AlbumSimpleWidget
 from lollypop.pop_album import AlbumPopover
 from lollypop.define import ArtSize
+from lollypop.controller_view import ViewController
 
 
-class AlbumsBoxView(LazyLoadingView):
+class AlbumsBoxView(FlowBoxView, ViewController):
     """
         Show albums in a box
     """
@@ -29,93 +30,55 @@ class AlbumsBoxView(LazyLoadingView):
             @param genre ids as [int]
             @param artist ids as [int]
         """
-        LazyLoadingView.__init__(self, True)
-        self.__signal = None
-        self.__current = None
-        self.__context_album_id = None
+        FlowBoxView.__init__(self)
+        ViewController.__init__(self)
+        self._widget_class = AlbumSimpleWidget
         self.__genre_ids = genre_ids
         self.__artist_ids = artist_ids
-        self.__press_rect = None
-
-        self._box = Gtk.FlowBox()
-        self._box.set_filter_func(self._filter_func)
-        self._box.set_selection_mode(Gtk.SelectionMode.NONE)
-        self._box.connect("child-activated", self.__on_album_activated)
-        # Allow lazy loading to not jump up and down
-        self._box.set_homogeneous(True)
-        self._box.set_max_children_per_line(1000)
-        self._box.show()
-
-        self._viewport.set_property("valign", Gtk.Align.START)
-        self._viewport.set_property("margin", 5)
-        self._scrolled.set_property("expand", True)
-
-        self.add(self._scrolled)
-
-    def populate(self, albums):
-        """
-            Populate albums
-            @param albums as [Album]
-        """
-        GLib.idle_add(self.__add_albums, albums)
-
-    @property
-    def children(self):
-        """
-            Return view children
-            @return [AlbumWidget]
-        """
-        children = []
-        for child in self._box.get_children():
-            children.append(child)
-        return children
+        self.connect_current_changed_signal()
+        self.connect_artwork_changed_signal("album")
 
 #######################
 # PROTECTED           #
 #######################
-
-#######################
-# PRIVATE             #
-#######################
-    def __add_albums(self, albums):
+    def _add_items(self, album_ids):
         """
             Add albums to the view
             Start lazy loading
-            @param [album ids as int]
+            @param album ids as [int]
         """
-        if self._stop:
-            self._stop = False
-            return
-        if albums:
-            widget = AlbumSimpleWidget(albums.pop(0),
-                                       self.__genre_ids,
-                                       self.__artist_ids)
-            widget.connect("overlayed", self._on_overlayed)
-            self._box.insert(widget, -1)
-            widget.show()
-            self._lazy_queue.append(widget)
-            GLib.idle_add(self.__add_albums, albums)
-        else:
-            GLib.idle_add(self.lazy_loading)
-            if self._viewport.get_child() is None:
-                self._viewport.add(self._box)
+        widget = FlowBoxView._add_items(self, album_ids,
+                                        self.__genre_ids, self.__artist_ids)
+        if widget is not None:
+            widget.connect("overlayed", self.on_overlayed)
 
-    def __on_album_activated(self, flowbox, album_widget):
+    def _on_current_changed(self, player):
+        """
+            Update children state
+            @param player as Player
+        """
+        for child in self._box.get_children():
+            child.set_selection()
+
+    def _on_artwork_changed(self, artwork, album_id):
+        """
+            Update children artwork if matching album id
+            @param artwork as Artwork
+            @param album_id as int
+        """
+        for child in self._box.get_children():
+            child.set_artwork(album_id)
+
+    def _on_album_activated(self, flowbox, album_widget):
         """
             Show Context view for activated album
             @param flowbox as Gtk.Flowbox
             @param album_widget as AlbumSimpleWidget
         """
-        # Here some code for touch screens
-        # If mouse pointer activate Gtk.FlowBoxChild, overlay is on,
-        # as enter notify event enabled it
-        # Else, we are in touch screen, first time show overlay, next time
-        # show popover
-        if not album_widget.is_overlay:
-            album_widget.show_overlay(True)
+        if FlowBoxView._on_album_activated(self, flowbox, album_widget):
             return
-        cover = album_widget.get_cover()
-        if cover is None:
+        artwork = album_widget.get_artwork()
+        if artwork is None:
             return
         # If widget top not on screen, popover will fail to show
         # FIXME: Report a bug and check always true
@@ -134,20 +97,20 @@ class AlbumsBoxView(LazyLoadingView):
         else:
             height = top_height
         popover = AlbumPopover(album_widget.album,
-                               self.__genre_ids,
-                               self.__artist_ids,
                                allocation.width,
                                height,
                                ArtSize.NONE)
-        popover.set_relative_to(cover)
+        popover.set_relative_to(artwork)
         popover.set_position(Gtk.PositionType.BOTTOM)
         album_widget.show_overlay(False)
         album_widget.lock_overlay(True)
         popover.connect("closed", self.__on_album_popover_closed, album_widget)
-        popover.show()
-        self.__current = album_widget
-        cover.set_opacity(0.9)
+        popover.popup()
+        artwork.set_opacity(0.9)
 
+#######################
+# PRIVATE             #
+#######################
     def __on_album_popover_closed(self, popover, album_widget):
         """
             Remove overlay and restore opacity
@@ -155,4 +118,4 @@ class AlbumsBoxView(LazyLoadingView):
             @param album_widget as AlbumWidget
         """
         album_widget.lock_overlay(False)
-        album_widget.get_cover().set_opacity(1)
+        album_widget.get_artwork().set_opacity(1)
