@@ -60,8 +60,8 @@ class ArtistView(ArtistAlbumsView):
         self._overlay.add_overlay(self.__grid)
         self.__empty = Gtk.Grid()
         self.__empty.show()
-        self._albumbox.add(self.__empty)
-        self._albumbox.set_row_spacing(20)
+        self._album_box.add(self.__empty)
+        self._album_box.set_row_spacing(20)
 
         self.__scale_factor = self.__artwork.get_scale_factor()
         self.__set_artwork()
@@ -87,12 +87,12 @@ class ArtistView(ArtistAlbumsView):
             Jump to current album
         """
         widget = None
-        for child in self._albumbox.get_children():
+        for child in self._album_box.get_children():
             if child.album.id == App().player.current_track.album.id:
                 widget = child
                 break
         if widget is not None:
-            y = widget.get_current_ordinate(self._albumbox)
+            y = widget.get_current_ordinate(self._album_box)
             self._scrolled.get_vadjustment().set_value(
                 y - self.__empty.get_property("height-request"))
 
@@ -198,18 +198,24 @@ class ArtistView(ArtistAlbumsView):
         """
         try:
             album_ids = App().albums.get_ids(self._artist_ids, self._genre_ids)
-            player_ids = [album.id for album in App().player.albums]
+            len_album_ids = len(album_ids)
+            player_album_ids = App().player.album_ids
+            len_player_album_ids = len(player_album_ids)
             icon_name = self.__add_button.get_image().get_icon_name()[0]
             add = icon_name == "list-add-symbolic"
             for album_id in album_ids:
-                in_player = album_id in player_ids
-                if add and not in_player:
+                if add and album_id not in player_album_ids:
                     App().player.add_album(Album(album_id))
-                elif not add and in_player:
-                    App().player.remove_album(Album(album_id))
+                elif not add and album_id in player_album_ids:
+                    if len_player_album_ids > len_album_ids and\
+                            App().player.current_track.album.id == album_id:
+                        App().player.skip_album()
+                    App().player.remove_album_by_id(album_id)
+            if len_player_album_ids == len_album_ids:
+                App().player.stop()
             self.__update_icon(not add)
-        except:
-            pass  # Artist not available anymore for this context
+        except Exception as e:
+            Logger.error("ArtistView::_on_add_clicked: %s" % e)
 
     def _on_jump_button_clicked(self, widget):
         """
@@ -225,7 +231,7 @@ class ArtistView(ArtistAlbumsView):
         popover = LastfmPopover()
         popover.set_relative_to(widget)
         popover.populate(self._artist_ids)
-        popover.show()
+        popover.popup()
 
     def _on_artwork_draw(self, image, ctx):
         """
@@ -402,7 +408,7 @@ class ArtistView(ArtistAlbumsView):
             @param album_id as int
         """
         albums = App().albums.get_ids(self._artist_ids, self._genre_ids)
-        album_ids = [album.id for album in App().player.albums]
+        album_ids = App().player.album_ids
         self.__update_icon(len(set(albums) & set(album_ids)) != len(albums))
 
     def __on_lock_changed(self, player):
