@@ -15,13 +15,13 @@ from gi.repository import Gtk, GLib, Gdk, Gio
 from gettext import gettext as _
 
 from lollypop.view import View
-from lollypop.widgets_playlist import PlaylistsWidget, PlaylistEditWidget
-from lollypop.widgets_playlist import PlaylistsManagerWidget
-from lollypop.define import App, Type, ArtSize
+from lollypop.widgets_playlist import PlaylistsWidget
+from lollypop.define import App, ArtSize
 from lollypop.objects import Track
+from lollypop.controller_view import ViewController
 
 
-class PlaylistsView(View):
+class PlaylistsView(View, ViewController):
     """
         Show playlist tracks
     """
@@ -33,6 +33,7 @@ class PlaylistsView(View):
             @param editable as bool
         """
         View.__init__(self, True)
+        ViewController.__init__(self)
         self.__autoscroll_timeout_id = None
         self.__prev_animated_rows = []
         self.__track_ids = []
@@ -48,7 +49,6 @@ class PlaylistsView(View):
         builder.get_object("title").set_label(
             ", ".join(App().playlists.get_names(playlist_ids)))
 
-        self.__edit_button = builder.get_object("edit-button")
         self.__jump_button = builder.get_object("jump-button")
         split_button = builder.get_object("split-button")
         if editable:
@@ -56,12 +56,6 @@ class PlaylistsView(View):
         else:
             split_button.hide()
 
-        if len(playlist_ids) > 1 or (
-           playlist_ids[0] < 0 and playlist_ids[0] not in [Type.LOVED,
-                                                           Type.NOPARTY]) or\
-                not editable:
-            self.__edit_button.hide()
-
         self.__playlists_widget = PlaylistsWidget(playlist_ids)
         self.__playlists_widget.set_filter_func(self._filter_func)
         self.__playlists_widget.show()
@@ -77,6 +71,7 @@ class PlaylistsView(View):
                            [], Gdk.DragAction.MOVE)
         self.drag_dest_add_text_targets()
         self.connect("drag-motion", self.__on_drag_motion)
+        self.connect_current_changed_signal()
 
         # No duration for non user playlists
         # FIXME
@@ -143,17 +138,17 @@ class PlaylistsView(View):
         """
         self.__playlists_widget.stop()
 
-    @property
-    def children(self):
-        """
-            Return view children
-            @return [PlaylistsWidget]
-        """
-        return [self.__playlists_widget]
-
 #######################
 # PROTECTED           #
 #######################
+    def _on_current_changed(self, player):
+        """
+            Update children state
+            @param player as Player
+        """
+        self.__update_jump_button()
+        self.__playlists_widget.set_playing_indicator()
+
     def _on_search_changed(self, entry):
         """
             Update filter
@@ -193,13 +188,6 @@ class PlaylistsView(View):
         if y is not None:
             self._scrolled.get_vadjustment().set_value(y)
 
-    def _on_edit_button_clicked(self, button):
-        """
-            Edit playlist
-            @param button as Gtk.Button
-        """
-        App().window.container.show_playlist_editor(self.__playlist_ids[0])
-
     def _on_save_button_clicked(self, button):
         """
             Save playlist as file
@@ -220,14 +208,6 @@ class PlaylistsView(View):
         filechooser.connect("response", self.__on_save_response)
         filechooser.run()
 
-    def _on_current_changed(self, player):
-        """
-            Current song changed, update playing button
-            @param player as Player
-        """
-        View._on_current_changed(self, player)
-        self.__update_jump_button()
-
 #######################
 # PRIVATE             #
 #######################
@@ -275,10 +255,13 @@ class PlaylistsView(View):
         if hours > 0:
             mins -= hours * 60
             if mins > 0:
+                # Duration hour minute
                 self.__duration_label.set_text(_("%s h  %s m") % (hours, mins))
             else:
+                # Duration hour minute
                 self.__duration_label.set_text(_("%s h") % hours)
         else:
+            # Duration hour minute
             self.__duration_label.set_text(_("%s m") % mins)
 
     def __update_jump_button(self):
@@ -366,92 +349,3 @@ class PlaylistsView(View):
         """
         if playlist_id in self.__playlist_ids:
             self.__playlists_widget.remove(track_id)
-
-
-class PlaylistsManageView(View):
-    """
-        Playlist view used to manage playlists
-    """
-
-    def __init__(self, object):
-        """
-            Init View
-            @param object as Track/Album/Disc
-        """
-        View.__init__(self)
-        builder = Gtk.Builder()
-        builder.add_from_resource(
-            "/org/gnome/Lollypop/PlaylistsManagerView.ui")
-        if object is not None:
-            builder.get_object("back_btn").show()
-        builder.connect_signals(self)
-        self.__manage_widget = PlaylistsManagerWidget(object)
-        self.__manage_widget.show()
-        self._viewport.add(self.__manage_widget)
-        self.add(builder.get_object("widget"))
-        self.add(self._scrolled)
-
-    def populate(self):
-        """
-            Populate the view
-        """
-        self.__manage_widget.populate()
-
-#######################
-# PROTECTED           #
-#######################
-    def _on_new_clicked(self, widget):
-        """
-            Add new playlist
-            @param widget as Gtk.Button
-        """
-        self.__manage_widget.add_new_playlist()
-
-    def _on_back_btn_clicked(self, button):
-        """
-            Restore previous view
-            @param button as Gtk.Button
-        """
-        App().window.container.destroy_current_view()
-
-
-class PlaylistEditView(View):
-    """
-        Playlist view used to edit playlists
-    """
-
-    def __init__(self, playlist_id):
-        """
-            Init view
-            @param playlist id as int
-            @param playlist name as int
-            @param width as int
-        """
-        View.__init__(self)
-        builder = Gtk.Builder()
-        builder.add_from_resource("/org/gnome/Lollypop/PlaylistEditView.ui")
-        builder.get_object("title").set_label(
-            App().playlists.get_name(playlist_id))
-        builder.connect_signals(self)
-        grid = builder.get_object("widget")
-        self.add(grid)
-        self.__edit_widget = PlaylistEditWidget(playlist_id)
-        self.__edit_widget.show()
-        self._viewport.add(self.__edit_widget)
-        self.add(self._scrolled)
-
-    def populate(self):
-        """
-            Populate view
-        """
-        self.__edit_widget.populate()
-
-#######################
-# PROTECTED           #
-#######################
-    def _on_back_btn_clicked(self, button):
-        """
-            Restore previous view
-            @param button as Gtk.Button
-        """
-        App().window.container.reload_view()
