@@ -15,11 +15,11 @@ from gi.repository import Gtk, GLib, Gdk
 from gettext import gettext as _
 
 from lollypop.define import App, ArtSize
-from lollypop.define import Shuffle, Loading
+from lollypop.define import Shuffle
 from lollypop.pop_artwork import CoversPopover
 
 
-class BaseWidget:
+class AlbumBaseWidget:
     """
         Base album widget
     """
@@ -28,38 +28,16 @@ class BaseWidget:
         """
             Init widget
         """
-        self.__loading = Loading.NONE
-        self._cover = None
+        self._artwork = None
         self._widget = None
         self._play_all_button = None
-        self._artwork_button = None
-        self._action_button = None
+        self._action2_button = None
+        self._action1_button = None
         self._show_overlay = False
         self._lock_overlay = True
         self._timeout_id = None
         self.__parent_filter = False
         self._overlay_orientation = Gtk.Orientation.HORIZONTAL
-        self._squared_class = "squared-icon"
-        self._rounded_class = "rounded-icon"
-
-    def update_playing_indicator(self):
-        """
-            Update playing indicator
-        """
-        pass
-
-    def update_duration(self, track_id):
-        """
-            Update duration for current track
-            @param track id as int
-        """
-        pass
-
-    def stop(self):
-        """
-            Stop populating
-        """
-        self.__loading = Loading.STOP
 
     def set_filtered(self, b):
         """
@@ -67,24 +45,6 @@ class BaseWidget:
         """
         self.__parent_filter = b
 
-    @property
-    def filter(self):
-        return ""
-
-    @property
-    def filtered(self):
-        """
-            True if filtered by parent
-        """
-        return self.__parent_filter
-
-    @property
-    def is_overlay(self):
-        """
-            True if overlayed or going to be
-        """
-        return self._show_overlay or self._timeout_id is not None
-
     def lock_overlay(self, lock):
         """
             Lock overlay
@@ -103,6 +63,24 @@ class BaseWidget:
             self._timeout_id = None
         self._show_overlay_func(set)
 
+    @property
+    def filter(self):
+        return ""
+
+    @property
+    def filtered(self):
+        """
+            True if filtered by parent
+        """
+        return self.__parent_filter
+
+    @property
+    def is_overlay(self):
+        """
+            True if overlayed or going to be
+        """
+        return self._show_overlay or self._timeout_id is not None
+
 #######################
 # PROTECTED           #
 #######################
@@ -137,46 +115,46 @@ class BaseWidget:
             if self._play_button is not None:
                 self._play_button.set_opacity(opacity)
                 self._play_button.get_style_context().add_class(
-                    self._rounded_class)
+                    "rounded-icon")
                 self._play_button.show()
             if self._play_all_button is not None:
                 self._play_all_button.set_opacity(opacity)
                 self._play_all_button.get_style_context().add_class(
-                    self._squared_class)
+                    "rounded-icon-small")
                 self._set_play_all_image()
                 self._play_all_button.show()
-            if self._artwork_button is not None:
-                self._artwork_button.set_opacity(1)
-                self._artwork_button.get_style_context().add_class(
-                    self._squared_class)
-                self._artwork_button.show()
-            if self._action_button is not None:
-                self._show_append(self._album not in App().player.albums)
-                self._action_button.set_opacity(opacity)
-                self._action_button.get_style_context().add_class(
-                    self._squared_class)
-                self._action_button.show()
+            if self._action2_button is not None:
+                self._action2_button.set_opacity(1)
+                self._action2_button.get_style_context().add_class(
+                    "rounded-icon-small")
+                self._action2_button.show()
+            if self._action1_button is not None:
+                self._show_append(self._album.id not in App().player.album_ids)
+                self._action1_button.set_opacity(opacity)
+                self._action1_button.get_style_context().add_class(
+                    "rounded-icon-small")
+                self._action1_button.show()
         else:
             if self._play_button is not None:
                 self._play_button.set_opacity(0)
                 self._play_button.hide()
                 self._play_button.get_style_context().remove_class(
-                    self._rounded_class)
+                    "rounded-icon")
             if self._play_all_button is not None:
                 self._play_all_button.set_opacity(0)
                 self._play_all_button.hide()
                 self._play_all_button.get_style_context().remove_class(
-                    self._squared_class)
-            if self._artwork_button is not None:
-                self._artwork_button.hide()
-                self._artwork_button.set_opacity(0)
-                self._artwork_button.get_style_context().remove_class(
-                    self._squared_class)
-            if self._action_button is not None:
-                self._action_button.hide()
-                self._action_button.set_opacity(0)
-                self._action_button.get_style_context().remove_class(
-                    self._squared_class)
+                    "rounded-icon-small")
+            if self._action2_button is not None:
+                self._action2_button.hide()
+                self._action2_button.set_opacity(0)
+                self._action2_button.get_style_context().remove_class(
+                    "rounded-icon-small")
+            if self._action1_button is not None:
+                self._action1_button.hide()
+                self._action1_button.set_opacity(0)
+                self._action1_button.get_style_context().remove_class(
+                    "rounded-icon-small")
 
     def _on_eventbox_realize(self, eventbox):
         """
@@ -193,7 +171,8 @@ class BaseWidget:
             @param widget as Gtk.Widget
             @param event es Gdk.Event
         """
-        self._cover.set_opacity(0.9)
+        if self._artwork is not None:
+            self._artwork.set_opacity(0.9)
         if self._timeout_id is None:
             self._timeout_id = GLib.timeout_add(250,
                                                 self.__on_enter_notify_timeout)
@@ -209,7 +188,8 @@ class BaseWidget:
            event.x >= allocation.width or\
            event.y <= 0 or\
            event.y >= allocation.height:
-            self._cover.set_opacity(1)
+            if self._artwork is not None:
+                self._artwork.set_opacity(1)
             # Remove enter notify timeout
             if self._timeout_id is not None:
                 GLib.source_remove(self._timeout_id)
@@ -225,6 +205,9 @@ class BaseWidget:
         """
         if App().player.locked:
             return True
+        if App().player.is_party:
+            action = App().lookup_action("party")
+            action.change_state(GLib.Variant("b", False))
         App().player.play_album(self._album)
         self._show_append(False)
         return True
@@ -237,9 +220,9 @@ class BaseWidget:
         """
         popover = CoversPopover(self._album)
         popover.set_relative_to(widget)
-        popover.connect("closed", self._on_pop_cover_closed)
+        popover.connect("closed", self._on_popover_closed)
         self._lock_overlay = True
-        popover.show()
+        popover.popup()
         return True
 
     def _on_action_press_event(self, widget, event):
@@ -251,19 +234,18 @@ class BaseWidget:
         """
         if App().player.locked:
             return True
-        if self._album in App().player.albums:
+        if self._album.id in App().player.album_ids:
             if App().player.current_track.album.id == self._album.id:
                 # If not last album, skip it
                 if len(App().player.albums) > 1:
                     App().player.skip_album()
-                    App().player.remove_album(self._album)
+                    App().player.remove_album_by_id(self._album.id)
                 # remove it and stop playback by going to next track
                 else:
-                    App().player.remove_album(self._album)
-                    App().player.set_next()
-                    App().player.next()
+                    App().player.remove_album_by_id(self._album.id)
+                    App().player.stop()
             else:
-                App().player.remove_album(self._album)
+                App().player.remove_album_by_id(self._album.id)
             self._show_append(True)
         else:
             if App().player.is_playing and not App().player.albums:
@@ -273,7 +255,7 @@ class BaseWidget:
             self._show_append(False)
         return True
 
-    def _on_pop_cover_closed(self, widget):
+    def _on_popover_closed(self, widget):
         """
             Remove selected style
             @param widget as Gtk.Popover
@@ -286,13 +268,13 @@ class BaseWidget:
             Show append button if append, else remove button
         """
         if append:
-            self._action_button.set_from_icon_name("list-add-symbolic",
-                                                   Gtk.IconSize.BUTTON)
-            self._action_event.set_tooltip_text(_("Add to current playlist"))
+            self._action1_button.set_from_icon_name("list-add-symbolic",
+                                                    Gtk.IconSize.BUTTON)
+            self._action1_event.set_tooltip_text(_("Add to current playlist"))
         else:
-            self._action_button.set_from_icon_name("list-remove-symbolic",
-                                                   Gtk.IconSize.BUTTON)
-            self._action_event.set_tooltip_text(
+            self._action1_button.set_from_icon_name("list-remove-symbolic",
+                                                    Gtk.IconSize.BUTTON)
+            self._action1_event.set_tooltip_text(
                 _("Remove from current playlist"))
 
 #######################
@@ -307,7 +289,7 @@ class BaseWidget:
             self._show_overlay_func(True)
 
 
-class AlbumWidget(BaseWidget):
+class AlbumWidget(AlbumBaseWidget):
     """
         Album widget
     """
@@ -316,13 +298,51 @@ class AlbumWidget(BaseWidget):
         """
             Init Album widget
         """
-        BaseWidget.__init__(self)
+        AlbumBaseWidget.__init__(self)
         self._album = album
         self._art_size = art_size
         self.connect("destroy", self.__on_destroy)
         self._scan_signal = App().scanner.connect("album-updated",
                                                   self._on_album_updated)
 
+    def get_artwork(self):
+        """
+            Get album artwork
+            @return Gtk.Image
+        """
+        return self._artwork
+
+    def set_artwork(self, album_id=None):
+        """
+            Set cover for album id
+            @param album_id as int
+        """
+        if self._artwork is None or\
+                (album_id is not None and album_id != self._album.id):
+            return
+        surface = App().art.get_album_artwork(
+            self._album,
+            self._art_size,
+            self._artwork.get_scale_factor())
+        self._artwork.set_from_surface(surface)
+        if surface.get_height() > surface.get_width():
+            self._overlay_orientation = Gtk.Orientation.VERTICAL
+        else:
+            self._overlay_orientation = Gtk.Orientation.HORIZONTAL
+
+    def set_selection(self):
+        """
+            Mark widget as selected if currently playing
+        """
+        if self._artwork is None or self._art_size != ArtSize.BIG:
+            return
+        selected = self._album.id == App().player.current_track.album.id
+        style_context = self._artwork.get_style_context()
+        if selected:
+            style_context.add_class("cover-frame-selected")
+        else:
+            style_context.remove_class("cover-frame-selected")
+
     @property
     def album(self):
         """
@@ -337,58 +357,6 @@ class AlbumWidget(BaseWidget):
         """
         return " ".join([self._album.name] + self._album.artists)
 
-    def get_cover(self):
-        """
-            Get album cover
-            @return cover as Gtk.Image
-        """
-        return self._cover
-
-    def set_cover(self):
-        """
-            Set cover for album if state changed
-        """
-        if self._cover is None:
-            return
-        surface = App().art.get_album_artwork(
-            self._album,
-            self._art_size,
-            self._cover.get_scale_factor())
-        self._cover.set_from_surface(surface)
-        if surface.get_height() > surface.get_width():
-            self._overlay_orientation = Gtk.Orientation.VERTICAL
-        else:
-            self._overlay_orientation = Gtk.Orientation.HORIZONTAL
-
-    def update_cover(self):
-        """
-            Update cover for current album
-        """
-        if self._cover is None:
-            return
-        surface = App().art.get_album_artwork(
-            self._album,
-            self._art_size,
-            self._cover.get_scale_factor())
-        self._cover.set_from_surface(surface)
-        if surface.get_height() > surface.get_width():
-            self._overlay_orientation = Gtk.Orientation.VERTICAL
-        else:
-            self._overlay_orientation = Gtk.Orientation.HORIZONTAL
-
-    def update_state(self):
-        """
-            Update widget state
-        """
-        if self._cover is None or self._art_size != ArtSize.BIG:
-            return
-        selected = self._album.id == App().player.current_track.album.id
-        style_context = self._cover.get_style_context()
-        if selected:
-            style_context.add_class("cover-frame-selected")
-        else:
-            style_context.remove_class("cover-frame-selected")
-
 #######################
 # PROTECTED           #
 #######################
