@@ -45,7 +45,6 @@ class AlbumDetailedWidget(Gtk.Bin, AlbumWidget, TracksView):
         Gtk.Bin.__init__(self)
         AlbumWidget.__init__(self, album, genre_ids, artist_ids, art_size)
         TracksView.__init__(self, ResponsiveType.FIXED)
-        self._rounded_class = "rounded-icon-small"
         self.__context = None
         # Cover + rating + spacing
         self.__height = ArtSize.BIG + 26
@@ -67,7 +66,7 @@ class AlbumDetailedWidget(Gtk.Bin, AlbumWidget, TracksView):
         self.__context_button = builder.get_object("context")
 
         if art_size == ArtSize.NONE:
-            self._cover = None
+            self._artwork = None
             rating = RatingWidget(self._album)
             rating.set_hexpand(True)
             rating.set_property("halign", Gtk.Align.END)
@@ -93,15 +92,15 @@ class AlbumDetailedWidget(Gtk.Bin, AlbumWidget, TracksView):
             builder.add_from_resource("/org/gnome/Lollypop/CoverBox.ui")
             builder.connect_signals(self)
             self._play_button = builder.get_object("play-button")
-            self._action_button = builder.get_object("action-button")
-            self._action_event = builder.get_object("action-event")
-            self._cover = builder.get_object("cover")
+            self._action1_button = builder.get_object("action-button")
+            self._action1_event = builder.get_object("action-event")
+            self._artwork = builder.get_object("cover")
             self.__coverbox = builder.get_object("coverbox")
             # 6 for 2*3px (application.css)
             self.__coverbox.set_property("width-request", art_size + 6)
             if art_size == ArtSize.BIG:
-                self._cover.get_style_context().add_class("cover-frame")
-                self._artwork_button = builder.get_object("artwork-button")
+                self._artwork.get_style_context().add_class("cover-frame")
+                self._action2_button = builder.get_object("artwork-button")
                 if self._album.year is not None:
                     self.__year_label.set_label(str(self._album.year))
                     self.__year_label.show()
@@ -127,7 +126,8 @@ class AlbumDetailedWidget(Gtk.Bin, AlbumWidget, TracksView):
                 # Here we are working around default CoverBox ui
                 # Do we really need to have another ui file?
                 # So just hack values on the fly
-                self._cover.get_style_context().add_class("small-cover-frame")
+                self._artwork.get_style_context().add_class(
+                    "small-cover-frame")
                 overlay_grid = builder.get_object("overlay-grid")
                 overlay_grid.set_margin_bottom(2)
                 overlay_grid.set_margin_end(2)
@@ -143,8 +143,8 @@ class AlbumDetailedWidget(Gtk.Bin, AlbumWidget, TracksView):
 
         album_info.add(self._responsive_widget)
 
-        self.set_cover()
-        self.update_state()
+        self.set_artwork()
+        self.set_selection()
 
         self.__title_label.set_label(self._album.name)
 
@@ -174,11 +174,11 @@ class AlbumDetailedWidget(Gtk.Bin, AlbumWidget, TracksView):
         for widget in self._tracks_widget_right.values():
             widget.set_filter_func(func)
 
-    def update_playing_indicator(self):
+    def set_playing_indicator(self):
         """
             Update playing indicator
         """
-        TracksView.update_playing_indicator(self)
+        TracksView.set_playing_indicator(self)
 
     def hide_header_labels(self):
         """
@@ -272,6 +272,21 @@ class AlbumDetailedWidget(Gtk.Bin, AlbumWidget, TracksView):
             else:
                 self.__coverbox.show()
 
+    def _on_eventbox_button_press_event(self, widget, event):
+        """
+            Show overlay if not shown
+            @param widget as Gtk.Widget
+            @param event as Gdk.Event
+        """
+        # Here some code for touch screens
+        # If mouse pointer activate Gtk.FlowBoxChild, overlay is on,
+        # as enter notify event enabled it
+        # Else, we are in touch screen, first time show overlay, next time
+        # show popover
+        if not self.is_overlay:
+            self.show_overlay(True)
+            return
+
 #######################
 # PRIVATE             #
 #######################
@@ -308,7 +323,7 @@ class AlbumDetailedWidget(Gtk.Bin, AlbumWidget, TracksView):
         else:
             popover.connect("closed", self.__on_pop_menu_closed)
             self.get_style_context().add_class("album-menu-selected")
-            popover.show()
+            popover.popup()
 
     def __on_pop_menu_closed(self, widget):
         """
