@@ -47,13 +47,12 @@ class AlbumSimpleWidget(Gtk.FlowBoxChild, AlbumWidget):
             Populate widget content
         """
         self.get_style_context().remove_class("loading")
-        self._rounded_class = "rounded-icon-small"
         self._widget = Gtk.EventBox()
         grid = Gtk.Grid()
         grid.set_orientation(Gtk.Orientation.VERTICAL)
-        self._cover = Gtk.Image()
-        self._cover.set_property("halign", Gtk.Align.CENTER)
-        self._cover.get_style_context().add_class("cover-frame")
+        self._artwork = Gtk.Image()
+        self._artwork.set_property("halign", Gtk.Align.CENTER)
+        self._artwork.get_style_context().add_class("cover-frame")
         self.__title_label = Gtk.Label()
         self.__title_label.set_ellipsize(Pango.EllipsizeMode.END)
         self.__title_label.set_property("halign", Gtk.Align.CENTER)
@@ -79,13 +78,12 @@ class AlbumSimpleWidget(Gtk.FlowBoxChild, AlbumWidget):
         self.__overlay.set_property("halign", Gtk.Align.CENTER)
         self.__overlay.set_property("valign", Gtk.Align.CENTER)
         self.__overlay_grid = Gtk.Grid()
-        self.__overlay_grid.set_column_spacing(6)
         self.__overlay_grid.set_row_spacing(6)
         self.__overlay_grid.set_margin_top(6)
         self.__overlay_grid.set_margin_bottom(6)
         self.__overlay_grid.set_margin_start(6)
         self.__overlay_grid.set_margin_end(6)
-        self.__overlay.add(self._cover)
+        self.__overlay.add(self._artwork)
         self.__overlay.add_overlay(self.__overlay_grid)
         color = Gtk.Grid()
         color.set_property("halign", Gtk.Align.CENTER)
@@ -96,8 +94,8 @@ class AlbumSimpleWidget(Gtk.FlowBoxChild, AlbumWidget):
         grid.add(self.__title_label)
         grid.add(artist_eventbox)
         self.add(self._widget)
-        self.set_cover()
-        self.update_state()
+        self.set_artwork()
+        self.set_selection()
         self._widget.set_property("halign", Gtk.Align.CENTER)
         self._widget.set_property("valign", Gtk.Align.CENTER)
         self.show_all()
@@ -137,39 +135,42 @@ class AlbumSimpleWidget(Gtk.FlowBoxChild, AlbumWidget):
                                      self._on_play_press_event)
             self._play_button = Gtk.Image.new_from_icon_name(
                 "media-playback-start-symbolic",
-                Gtk.IconSize.BUTTON)
+                Gtk.IconSize.DND)
             self._play_button.set_opacity(0)
             # Play all button
             self._play_all_event = Gtk.EventBox()
             self._play_all_event.set_property("has-tooltip", True)
             self._play_all_event.set_tooltip_text(_("Play albums"))
             self._play_all_event.set_property("halign", Gtk.Align.END)
+            self._play_all_event.set_property("valign", Gtk.Align.END)
             self._play_all_event.connect("realize", self._on_eventbox_realize)
             self._play_all_event.connect("button-press-event",
                                          self.__on_play_all_press_event)
             self._play_all_button = Gtk.Image.new()
             self._play_all_button.set_opacity(0)
             # Artwork button
-            self._artwork_event = Gtk.EventBox()
-            self._artwork_event.set_property("has-tooltip", True)
-            self._artwork_event.set_tooltip_text(_("Change artwork"))
-            self._artwork_event.set_property("halign", Gtk.Align.END)
-            self._artwork_event.connect("realize", self._on_eventbox_realize)
-            self._artwork_event.connect("button-press-event",
+            self._action2_event = Gtk.EventBox()
+            self._action2_event.set_property("has-tooltip", True)
+            self._action2_event.set_tooltip_text(_("Change artwork"))
+            self._action2_event.set_property("halign", Gtk.Align.END)
+            self._action2_event.set_property("valign", Gtk.Align.END)
+            self._action2_event.connect("realize", self._on_eventbox_realize)
+            self._action2_event.connect("button-press-event",
                                         self._on_artwork_press_event)
-            self._artwork_button = Gtk.Image.new_from_icon_name(
+            self._action2_button = Gtk.Image.new_from_icon_name(
                 "image-x-generic-symbolic",
                 Gtk.IconSize.BUTTON)
-            self._artwork_button.set_opacity(0)
+            self._action2_button.set_opacity(0)
             # Action button
-            self._action_event = Gtk.EventBox()
-            self._action_event.set_property("has-tooltip", True)
-            self._action_event.set_property("halign", Gtk.Align.END)
-            self._action_event.connect("realize", self._on_eventbox_realize)
-            self._action_event.connect("button-press-event",
-                                       self._on_action_press_event)
-            self._action_button = Gtk.Image.new()
-            self._action_button.set_opacity(0)
+            self._action1_event = Gtk.EventBox()
+            self._action1_event.set_property("has-tooltip", True)
+            self._action1_event.set_property("halign", Gtk.Align.END)
+            self._action1_event.set_property("valign", Gtk.Align.END)
+            self._action1_event.connect("realize", self._on_eventbox_realize)
+            self._action1_event.connect("button-press-event",
+                                        self._on_action_press_event)
+            self._action1_button = Gtk.Image.new()
+            self._action1_button.set_opacity(0)
             self.__overlay_grid.set_orientation(self._overlay_orientation)
             if self._overlay_orientation == Gtk.Orientation.VERTICAL:
                 self._play_event.set_hexpand(False)
@@ -187,12 +188,12 @@ class AlbumSimpleWidget(Gtk.FlowBoxChild, AlbumWidget):
                 self.__overlay_grid.set_property("valign", Gtk.Align.END)
             self._play_event.add(self._play_button)
             self._play_all_event.add(self._play_all_button)
-            self._artwork_event.add(self._artwork_button)
-            self._action_event.add(self._action_button)
+            self._action2_event.add(self._action2_button)
+            self._action1_event.add(self._action1_button)
             self.__overlay_grid.add(self._play_event)
             self.__overlay_grid.add(self._play_all_event)
-            self.__overlay_grid.add(self._action_event)
-            self.__overlay_grid.add(self._artwork_event)
+            self.__overlay_grid.add(self._action1_event)
+            self.__overlay_grid.add(self._action2_event)
             self.__overlay_grid.show_all()
             AlbumWidget._show_overlay_func(self, True)
         else:
@@ -205,14 +206,14 @@ class AlbumSimpleWidget(Gtk.FlowBoxChild, AlbumWidget):
             self._play_all_event = None
             self._play_all_button.destroy()
             self._play_all_button = None
-            self._action_event.destroy()
-            self._action_event = None
-            self._action_button.destroy()
-            self._action_button = None
-            self._artwork_event.destroy()
-            self._artwork_event = None
-            self._artwork_button.destroy()
-            self._artwork_button = None
+            self._action1_event.destroy()
+            self._action1_event = None
+            self._action1_button.destroy()
+            self._action1_button = None
+            self._action2_event.destroy()
+            self._action2_event = None
+            self._action2_button.destroy()
+            self._action2_button = None
 
     def _on_album_updated(self, scanner, album_id, destroy):
         """
@@ -239,12 +240,12 @@ class AlbumSimpleWidget(Gtk.FlowBoxChild, AlbumWidget):
         self._show_append(False)
         if App().player.is_party:
             App().lookup_action("party").change_state(GLib.Variant("b", False))
-        App().player.clear_albums()
         if App().settings.get_enum("shuffle") == Shuffle.TRACKS:
             track = choice(self._album.tracks)
         else:
             track = self._album.tracks[0]
         if App().window.container.view.filtered:
+            App().player.clear_albums()
             # Here we need to get ids from parent as view may be filtered
             for child in self.get_parent().get_children():
                 if not child.filtered:
@@ -252,7 +253,7 @@ class AlbumSimpleWidget(Gtk.FlowBoxChild, AlbumWidget):
         else:
             App().player.play_albums(track,
                                      self._album.genre_ids,
-                                     [])
+                                     self._album.artist_ids)
         return True
 
     def _on_query_tooltip(self, eventbox, x, y, keyboard, tooltip):
@@ -281,12 +282,12 @@ class AlbumSimpleWidget(Gtk.FlowBoxChild, AlbumWidget):
 
     def __on_button_press(self, eventbox, event):
         """
-            Store pressed button
+            Handle album mouse click
             @param eventbox as Gtk.EventBox
             @param event as Gdk.EventButton
         """
         if event.button != 1:
-            popover = Gtk.Popover.new_from_model(self._cover,
+            popover = Gtk.Popover.new_from_model(self._artwork,
                                                  AlbumMenu(self._album,
                                                            True))
             popover.set_position(Gtk.PositionType.BOTTOM)
@@ -296,7 +297,7 @@ class AlbumSimpleWidget(Gtk.FlowBoxChild, AlbumWidget):
             rect.width = rect.height = 1
             popover.set_pointing_to(rect)
             popover.connect("closed", self.__on_album_popover_closed)
-            popover.show()
+            popover.popup()
 
     def __on_artist_button_press(self, eventbox, event):
         """
@@ -314,4 +315,4 @@ class AlbumSimpleWidget(Gtk.FlowBoxChild, AlbumWidget):
             @param album_widget as AlbumWidget
         """
         self.lock_overlay(False)
-        self.get_cover().set_opacity(1)
+        self.get_artwork().set_opacity(1)
