@@ -16,11 +16,11 @@ from gettext import gettext as _
 
 from lollypop.define import App, ArtSize, Type
 from lollypop.objects import Track
-from lollypop.widgets_album import BaseWidget
+from lollypop.widgets_album import AlbumBaseWidget
 from lollypop.pop_radio import RadioPopover
 
 
-class RadioWidget(Gtk.FlowBoxChild, BaseWidget):
+class RadioWidget(Gtk.FlowBoxChild, AlbumBaseWidget):
     """
         Widget with radio cover and title
     """
@@ -28,17 +28,18 @@ class RadioWidget(Gtk.FlowBoxChild, BaseWidget):
         "overlayed": (GObject.SignalFlags.RUN_FIRST, None, (bool,))
     }
 
-    def __init__(self, name, radios_manager):
+    def __init__(self, radio_id, radios):
         """
             Init radio widget
-            @param name as string
-            @param radios_manager as RadiosManager
+            @param radio_id as int
+            @param radios as Radios
         """
         Gtk.FlowBoxChild.__init__(self)
-        BaseWidget.__init__(self)
+        AlbumBaseWidget.__init__(self)
         self.get_style_context().add_class("loading")
-        self.__name = name
-        self.__radios_manager = radios_manager
+        self.__radio_id = radio_id
+        self.__name = radios.get_name(radio_id)
+        self.__radios = radios
 
     def populate(self):
         """
@@ -73,8 +74,8 @@ class RadioWidget(Gtk.FlowBoxChild, BaseWidget):
         self.set_property("halign", Gtk.Align.CENTER)
         self.set_property("valign", Gtk.Align.CENTER)
         self.add(self._widget)
-        self.set_cover()
-        self.update_state()
+        self.set_artwork()
+        self.set_selection()
         self.show_all()
         self._lock_overlay = False
 
@@ -102,11 +103,12 @@ class RadioWidget(Gtk.FlowBoxChild, BaseWidget):
         self.__name = name
         self.__title_label.set_label(name)
 
-    def set_cover(self):
+    def set_artwork(self, name=None):
         """
-            Set cover for album if state changed
+            Set artwork for radio matching name
         """
-        if self._cover is None:
+        if self._cover is None or\
+                (name is not None and name != self.__name):
             return
         surface = App().art.get_radio_artwork(
             self.__name,
@@ -114,21 +116,9 @@ class RadioWidget(Gtk.FlowBoxChild, BaseWidget):
             self._cover.get_scale_factor())
         self._cover.set_from_surface(surface)
 
-    def update_cover(self):
+    def set_selection(self):
         """
-            Update cover for radio
-        """
-        if self._cover is None:
-            return
-        surface = App().art.get_radio_artwork(
-            self.__name,
-            ArtSize.BIG,
-            self._cover.get_scale_factor())
-        self._cover.set_from_surface(surface)
-
-    def update_state(self):
-        """
-            Update widget state
+            Mark widget as selected if currently playing
         """
         if self._cover is None:
             return
@@ -175,11 +165,13 @@ class RadioWidget(Gtk.FlowBoxChild, BaseWidget):
         if set:
             # Play button
             self._play_event = Gtk.EventBox()
+            self._play_event.set_margin_start(6)
+            self._play_event.set_margin_bottom(6)
             self._play_event.set_property("has-tooltip", True)
             self._play_event.set_tooltip_text(_("Play"))
             self._play_event.set_hexpand(True)
-            self._play_event.set_property("valign", Gtk.Align.CENTER)
-            self._play_event.set_property("halign", Gtk.Align.CENTER)
+            self._play_event.set_property("valign", Gtk.Align.END)
+            self._play_event.set_property("halign", Gtk.Align.START)
             self._play_event.connect("realize", self._on_eventbox_realize)
             self._play_event.connect("button-press-event",
                                      self._on_play_press_event)
@@ -188,37 +180,36 @@ class RadioWidget(Gtk.FlowBoxChild, BaseWidget):
                 Gtk.IconSize.DND)
             self._play_button.set_opacity(0)
             # Edit button
-            self._artwork_event = Gtk.EventBox()
-            self._artwork_event.set_margin_bottom(5)
-            self._artwork_event.set_margin_end(5)
-            self._artwork_event.set_property("has-tooltip", True)
-            self._artwork_event.set_tooltip_text(_("Modify radio"))
-            self._artwork_event.set_property("halign", Gtk.Align.END)
-            self._artwork_event.connect("realize", self._on_eventbox_realize)
-            self._artwork_event.connect("button-press-event",
+            self._action2_event = Gtk.EventBox()
+            self._action2_event.set_margin_bottom(6)
+            self._action2_event.set_margin_end(6)
+            self._action2_event.set_property("has-tooltip", True)
+            self._action2_event.set_tooltip_text(_("Modify radio"))
+            self._action2_event.connect("realize", self._on_eventbox_realize)
+            self._action2_event.connect("button-press-event",
                                         self._on_edit_press_event)
-            self._artwork_event.set_property("valign", Gtk.Align.END)
-            self._artwork_event.set_property("halign", Gtk.Align.END)
-            self._artwork_button = Gtk.Image.new_from_icon_name(
+            self._action2_event.set_property("valign", Gtk.Align.END)
+            self._action2_event.set_property("halign", Gtk.Align.END)
+            self._action2_button = Gtk.Image.new_from_icon_name(
                 "document-properties-symbolic",
                 Gtk.IconSize.BUTTON)
-            self._artwork_button.set_opacity(0)
+            self._action2_button.set_opacity(0)
             self._play_event.add(self._play_button)
-            self._artwork_event.add(self._artwork_button)
+            self._action2_event.add(self._action2_button)
             self.__overlay.add_overlay(self._play_event)
-            self.__overlay.add_overlay(self._artwork_event)
+            self.__overlay.add_overlay(self._action2_event)
             self.__overlay.show_all()
-            BaseWidget._show_overlay_func(self, True)
+            AlbumBaseWidget._show_overlay_func(self, True)
         else:
-            BaseWidget._show_overlay_func(self, False)
+            AlbumBaseWidget._show_overlay_func(self, False)
             self._play_event.destroy()
             self._play_event = None
             self._play_button.destroy()
             self._play_button = None
-            self._artwork_event.destroy()
-            self._artwork_event = None
-            self._artwork_button.destroy()
-            self._artwork_button = None
+            self._action2_event.destroy()
+            self._action2_event = None
+            self._action2_button.destroy()
+            self._action2_button = None
 
 #######################
 # PRIVATE             #
@@ -246,7 +237,7 @@ class RadioWidget(Gtk.FlowBoxChild, BaseWidget):
         """
         if App().player.locked:
             return True
-        url = self.__radios_manager.get_url(self.__name)
+        url = self.__radios.get_url(self.__name)
         if url:
             track = Track()
             track.set_radio(self.__name, url)
@@ -258,8 +249,8 @@ class RadioWidget(Gtk.FlowBoxChild, BaseWidget):
             @param: widget as Gtk.EventBox
             @param: event as Gdk.Event
         """
-        popover = RadioPopover(self.__name, self.__radios_manager)
+        popover = RadioPopover(self.__name, self.__radios)
         popover.set_relative_to(widget)
-        popover.connect("closed", self._on_pop_cover_closed)
+        popover.connect("closed", self._on_popover_closed)
         self._lock_overlay = True
-        popover.show()
+        popover.popup()
