@@ -133,14 +133,6 @@ class Row(Gtk.ListBoxRow):
             else:
                 self._indicator.empty()
 
-    def update_duration(self):
-        """
-            Update duration for row
-        """
-        # Get a new track to get new duration (cache)
-        track = Track(self._track.id)
-        self._duration_label.set_text(seconds_to_string(track.duration))
-
     def update_num_label(self):
         """
             Update position label for row
@@ -203,7 +195,7 @@ class Row(Gtk.ListBoxRow):
         popover.set_pointing_to(rect)
         popover.connect("closed", self.__on_closed)
         self.get_style_context().add_class("track-menu-selected")
-        popover.show()
+        popover.popup()
 
     def __on_map(self, widget):
         """
@@ -470,8 +462,12 @@ class PlaylistRow(Row):
                 self.get_scale_factor())
             self.__cover.set_from_surface(surface)
             self.__cover.show()
+            self.__cover.set_margin_top(2)
+            self.set_margin_bottom(2)
             self.__header.show_all()
         else:
+            self.__cover.set_margin_top(0)
+            self.set_margin_bottom(0)
             self.__cover.set_tooltip_text("")
             self.__cover.clear()
             self.__cover.hide()
@@ -726,15 +722,6 @@ class TracksWidget(Gtk.ListBox):
             row.set_indicator(row.track.id == track_id,
                               Track(row.track.id).loved)
 
-    def update_duration(self, track_id):
-        """
-            Update playing track
-            @param track id as int
-        """
-        for row in self.get_children():
-            if row.id == track_id:
-                row.update_duration()
-
     def show_spinner(self, track_id):
         """
             Show spinner for track_id
